# MKTimeline - a static site generator for interactive/visual timelines
A tool for creating interactive/visual timelines.

This tool is under development and is considered BETA.
As you can see, there is no documentation yet.
Use at your own risk and befuddlement.
